@@ -32,10 +32,10 @@ from pymatgen.core.operations import SymmOp
 
 
 class CifParser(object):
-    '''
+    """
     A wrapper class around PyCifRW to read Cif and convert into a pymatgen
     Structure object.
-    '''
+    """
 
     def __init__(self, filename, occupancy_tolerance=1.):
         """
@@ -79,23 +79,23 @@ class CifParser(object):
         """
         Generate structure from part of the cif.
         """
-        spacegroup = data.get('_symmetry_space_group_name_H-M', 'P1')
+        spacegroup = data.get("_symmetry_space_group_name_H-M", "P1")
 
         if len(spacegroup) == 0:
             latt_type = "P"
         else:
             latt_type = spacegroup[0]
-        lengths = [float_from_str(data['_cell_length_' + i])
-                   for i in ['a', 'b', 'c']]
-        angles = [float_from_str(data['_cell_angle_' + i])
-                  for i in ['alpha', 'beta', 'gamma']]
+        lengths = [float_from_str(data["_cell_length_" + i])
+                   for i in ["a", "b", "c"]]
+        angles = [float_from_str(data["_cell_angle_" + i])
+                  for i in ["alpha", "beta", "gamma"]]
         lattice = Lattice.from_lengths_and_angles(lengths, angles)
         primlattice = lattice.get_primitive_lattice(latt_type)
         try:
-            sympos = data['_symmetry_equiv_pos_as_xyz']
+            sympos = data["_symmetry_equiv_pos_as_xyz"]
         except:
             try:
-                sympos = data['_symmetry_equiv_pos_as_xyz_']
+                sympos = data["_symmetry_equiv_pos_as_xyz_"]
             except:
                 warnings.warn("No _symmetry_equiv_pos_as_xyz type key found. "
                               "Defaulting to P1.")
@@ -106,31 +106,31 @@ class CifParser(object):
             m = re.search("([A-Z][a-z]*)", sym)
             if m:
                 return m.group(1)
-            return ''
+            return ""
 
         #oxi_states = None
         try:
             oxi_states = dict()
-            for i in xrange(len(data['_atom_type_symbol'])):
-                oxi_states[data['_atom_type_symbol'][i]] = \
-                    float_from_str(data['_atom_type_oxidation_number'][i])
+            for i in xrange(len(data["_atom_type_symbol"])):
+                oxi_states[data["_atom_type_symbol"][i]] = \
+                    float_from_str(data["_atom_type_oxidation_number"][i])
         except:
             oxi_states = None
 
         coord_to_species = OrderedDict()
 
-        for i in xrange(len(data['_atom_site_type_symbol'])):
-            symbol = parse_symbol(data['_atom_site_type_symbol'][i])
+        for i in xrange(len(data["_atom_site_type_symbol"])):
+            symbol = parse_symbol(data["_atom_site_type_symbol"][i])
             if oxi_states is not None:
                 el = Specie(symbol,
-                            oxi_states[data['_atom_site_type_symbol'][i]])
+                            oxi_states[data["_atom_site_type_symbol"][i]])
             else:
                 el = Element(symbol)
-            x = float_from_str(data['_atom_site_fract_x'][i])
-            y = float_from_str(data['_atom_site_fract_y'][i])
-            z = float_from_str(data['_atom_site_fract_z'][i])
+            x = float_from_str(data["_atom_site_fract_x"][i])
+            y = float_from_str(data["_atom_site_fract_y"][i])
+            z = float_from_str(data["_atom_site_fract_z"][i])
             try:
-                occu = float_from_str(data['_atom_site_occupancy'][i])
+                occu = float_from_str(data["_atom_site_occupancy"][i])
             except:
                 occu = 1
             if occu > 0:
@@ -163,7 +163,7 @@ class CifParser(object):
         return struct.get_sorted_structure()
 
     def get_structures(self, primitive=True):
-        '''
+        """
         Return list of structures in CIF file. primitive boolean sets whether a
         conventional cell structure or primitive cell structure is returned.
 
@@ -174,7 +174,7 @@ class CifParser(object):
 
         Returns:
             List of Structures.
-        '''
+        """
         return [self._get_structure(v, primitive)
                 for k, v in self._cif.items()]
 
@@ -189,9 +189,9 @@ class CifParser(object):
 
 
 class CifWriter:
-    '''
+    """
     A wrapper around PyCifRW to write CIF files from pymatgen structures.
-    '''
+    """
 
     def __init__(self, struct):
         """
@@ -203,29 +203,29 @@ class CifWriter:
         latt = struct.lattice
         comp = struct.composition
         no_oxi_comp = Composition.from_formula(comp.formula)
-        block['_symmetry_space_group_name_H-M'] = 'P 1'
-        block['_cell_length_a'] = str(latt.a)
-        block['_cell_length_b'] = str(latt.b)
-        block['_cell_length_c'] = str(latt.c)
-        block['_cell_angle_alpha'] = str(latt.alpha)
-        block['_cell_angle_beta'] = str(latt.beta)
-        block['_cell_angle_gamma'] = str(latt.gamma)
-        block['_chemical_name_systematic'] = "Generated by pymatgen"
-        block['_symmetry_Int_Tables_number'] = 1
-        block['_chemical_formula_structural'] = str(no_oxi_comp
+        block["_symmetry_space_group_name_H-M"] = "P 1"
+        block["_cell_length_a"] = str(latt.a)
+        block["_cell_length_b"] = str(latt.b)
+        block["_cell_length_c"] = str(latt.c)
+        block["_cell_angle_alpha"] = str(latt.alpha)
+        block["_cell_angle_beta"] = str(latt.beta)
+        block["_cell_angle_gamma"] = str(latt.gamma)
+        block["_chemical_name_systematic"] = "Generated by pymatgen"
+        block["_symmetry_Int_Tables_number"] = 1
+        block["_chemical_formula_structural"] = str(no_oxi_comp
                                                     .reduced_formula)
-        block['_chemical_formula_sum'] = str(no_oxi_comp.formula)
-        block['_cell_volume'] = str(latt.volume)
+        block["_chemical_formula_sum"] = str(no_oxi_comp.formula)
+        block["_cell_volume"] = str(latt.volume)
 
         reduced_comp = Composition.from_formula(no_oxi_comp.reduced_formula)
         el = no_oxi_comp.elements[0]
         amt = comp[el]
         fu = int(amt / reduced_comp[Element(el.symbol)])
 
-        block['_cell_formula_units_Z'] = str(fu)
-        block.AddCifItem(([['_symmetry_equiv_pos_site_id',
-                            '_symmetry_equiv_pos_as_xyz']],
-                          [[['1'], ['x, y, z']]]))
+        block["_cell_formula_units_Z"] = str(fu)
+        block.AddCifItem(([["_symmetry_equiv_pos_site_id",
+                            "_symmetry_equiv_pos_as_xyz"]],
+                          [[["1"], ["x, y, z"]]]))
 
         contains_oxidation = True
         symbol_to_oxinum = dict()
@@ -235,8 +235,8 @@ class CifWriter:
             symbol_to_oxinum = {el.symbol: 0 for el in comp.elements}
             contains_oxidation = False
         if contains_oxidation:
-            block.AddCifItem(([['_atom_type_symbol',
-                                '_atom_type_oxidation_number']],
+            block.AddCifItem(([["_atom_type_symbol",
+                                "_atom_type_oxidation_number"]],
                               [[symbol_to_oxinum.keys(),
                                 symbol_to_oxinum.values()]]))
 
@@ -253,36 +253,36 @@ class CifWriter:
         for site in struct:
             for sp, occu in site.species_and_occu.items():
                 atom_site_type_symbol.append(str(sp))
-                atom_site_symmetry_multiplicity.append('1')
-                atom_site_fract_x.append(str('{0:f}'.format(site.a)))
-                atom_site_fract_y.append(str('{0:f}'.format(site.b)))
-                atom_site_fract_z.append(str('{0:f}'.format(site.c)))
-                atom_site_attached_hydrogens.append('0')
-                atom_site_B_iso_or_equiv.append('.')
+                atom_site_symmetry_multiplicity.append("1")
+                atom_site_fract_x.append(str("{0:f}".format(site.a)))
+                atom_site_fract_y.append(str("{0:f}".format(site.b)))
+                atom_site_fract_z.append(str("{0:f}".format(site.c)))
+                atom_site_attached_hydrogens.append("0")
+                atom_site_B_iso_or_equiv.append(".")
                 atom_site_label.append(str(sp.symbol) + str(count))
                 atom_site_occupancy.append(str(occu))
                 count += 1
 
-        block['_atom_site_type_symbol'] = atom_site_type_symbol
-        block.AddToLoop('_atom_site_type_symbol',
-                        {'_atom_site_label': atom_site_label})
-        block.AddToLoop('_atom_site_type_symbol',
-                        {'_atom_site_symmetry_multiplicity':
+        block["_atom_site_type_symbol"] = atom_site_type_symbol
+        block.AddToLoop("_atom_site_type_symbol",
+                        {"_atom_site_label": atom_site_label})
+        block.AddToLoop("_atom_site_type_symbol",
+                        {"_atom_site_symmetry_multiplicity":
                          atom_site_symmetry_multiplicity})
-        block.AddToLoop('_atom_site_type_symbol',
-                        {'_atom_site_fract_x': atom_site_fract_x})
-        block.AddToLoop('_atom_site_type_symbol',
-                        {'_atom_site_fract_y': atom_site_fract_y})
-        block.AddToLoop('_atom_site_type_symbol',
-                        {'_atom_site_fract_z': atom_site_fract_z})
-        block.AddToLoop('_atom_site_type_symbol',
-                        {'_atom_site_attached_hydrogens':
+        block.AddToLoop("_atom_site_type_symbol",
+                        {"_atom_site_fract_x": atom_site_fract_x})
+        block.AddToLoop("_atom_site_type_symbol",
+                        {"_atom_site_fract_y": atom_site_fract_y})
+        block.AddToLoop("_atom_site_type_symbol",
+                        {"_atom_site_fract_z": atom_site_fract_z})
+        block.AddToLoop("_atom_site_type_symbol",
+                        {"_atom_site_attached_hydrogens":
                          atom_site_attached_hydrogens})
-        block.AddToLoop('_atom_site_type_symbol',
-                        {'_atom_site_B_iso_or_equiv':
+        block.AddToLoop("_atom_site_type_symbol",
+                        {"_atom_site_B_iso_or_equiv":
                          atom_site_B_iso_or_equiv})
-        block.AddToLoop('_atom_site_type_symbol',
-                        {'_atom_site_occupancy': atom_site_occupancy})
+        block.AddToLoop("_atom_site_type_symbol",
+                        {"_atom_site_occupancy": atom_site_occupancy})
 
         self._cf = CifFile.CifFile()
         # AJ says: CIF Block names cannot be more than 75 characters or you
@@ -290,16 +290,16 @@ class CifWriter:
         self._cf[comp.reduced_formula[0:74]] = block
 
     def __str__(self):
-        '''
+        """
         Returns the cif as a string.
-        '''
+        """
         return str(self._cf)
 
     def write_file(self, filename):
-        '''
+        """
         Write the cif file.
-        '''
-        with open(filename, 'w') as f:
+        """
+        with open(filename, "w") as f:
             f.write(self.__str__())
 
 
@@ -325,10 +325,10 @@ def coord_in_list(coord, coord_list, tol):
 
 
 def float_from_str(text):
-    '''
+    """
     Remove uncertainty brackets from strings and return the float.
-    '''
-    return float(re.sub('\(\d+\)', '', text))
+    """
+    return float(re.sub("\(\d+\)", "", text))
 
 
 def parse_symmetry_operations(symmops_str):
@@ -348,7 +348,6 @@ def parse_symmetry_operations(symmops_str):
                     if m.group(3) != "":
                         num = num / float(m.group(3))
                     trans[i] = factor * num
-        op = SymmOp.from_rotation_matrix_and_translation_vector(rot_matrix,
-                                                                trans)
+        op = SymmOp.from_rotation_and_translation(rot_matrix, trans)
         ops.append(op)
     return ops
