@@ -11,14 +11,14 @@ __maintainer__ = "Shyue Ping Ong"
 __email__ = "shyue@mit.edu"
 __date__ = "Sep 23, 2011"
 
-
 import abc
 
 from pymatgen.serializers.json_coders import MSONable
 
+
 class AbstractTransformation(MSONable):
     """
-    Abstract transformation class.    
+    Abstract transformation class.
     """
     __metaclass__ = abc.ABCMeta
 
@@ -28,7 +28,7 @@ class AbstractTransformation(MSONable):
         Applies the transformation to a structure. Depending on whether a
         transformation is one-to-many, there may be an option to return a
         ranked list of structures.
-        
+
         Args:
             structure:
                 input structure
@@ -36,17 +36,17 @@ class AbstractTransformation(MSONable):
                 Boolean stating whether or not multiple structures are
                 returned. If return_ranked_list is a number, that number of
                 structures is returned.
-                
+
         Returns:
-            depending on returned_ranked list, either a transformed structure 
+            depending on returned_ranked list, either a transformed structure
             or
-            a list of dictionaries, where each dictionary is of the form 
+            a list of dictionaries, where each dictionary is of the form
             {'structure' = .... , 'other_arguments'}
             the key 'transformation' is reserved for the transformation that
-            was actually applied to the structure. 
+            was actually applied to the structure.
             This transformation is parsed by the alchemy classes for generating
             a more specific transformation history. Any other information will
-            be stored in the transformation_parameters dictionary in the 
+            be stored in the transformation_parameters dictionary in the
             transmuted structure class.
         '''
         return
@@ -63,9 +63,10 @@ class AbstractTransformation(MSONable):
     def is_one_to_many(self):
         '''
         Determines if a Transformation is a one-to-many transformation. If a
-        Transformation is a one-to-many transformation, the apply_transformation
-        method should have a keyword arg "return_ranked_list" which allows for
-        the transformed structures to be returned as a ranked list.
+        Transformation is a one-to-many transformation, the
+        apply_transformation method should have a keyword arg
+        "return_ranked_list" which allows for the transformed structures to be
+        returned as a ranked list.
         '''
         return False
 
@@ -74,7 +75,8 @@ class AbstractTransformation(MSONable):
         for trans_modules in ['standard_transformations',
                               'site_transformations',
                               'advanced_transformations']:
-            mod = __import__('pymatgen.transformations.' + trans_modules, globals(), locals(), [d['name']], -1)
+            mod = __import__('pymatgen.transformations.' + trans_modules,
+                             globals(), locals(), [d['name']], -1)
             if hasattr(mod, d['name']):
                 trans = getattr(mod, d['name'])
                 return trans(**d['init_args'])
